# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['poetry_dynamic_versioning']

package_data = \
{'': ['*']}

install_requires = \
['dunamai>=1.16.0,<2.0.0', 'jinja2>=2.11.1,<4', 'tomlkit>=0.4']

extras_require = \
{'plugin': ['poetry>=1.2.0,<2.0.0']}

entry_points = \
{'console_scripts': ['poetry-dynamic-versioning = '
                     'poetry_dynamic_versioning.__main__:main'],
 'poetry.application.plugin': ['poetry-dynamic-versioning = '
                               'poetry_dynamic_versioning.plugin:DynamicVersioningPlugin']}

setup_kwargs = {
    'name': 'poetry-dynamic-versioning',
    'version': '0.21.4',
    'description': 'Plugin for Poetry to enable dynamic versioning based on VCS tags',
    'long_description': '# Dynamic versioning plugin for Poetry\nThis is a Python 3.7+ plugin for [Poetry 1.2.0+](https://github.com/sdispater/poetry)\nand [Poetry Core 1.0.0+](https://github.com/python-poetry/poetry-core)\nto enable dynamic versioning based on tags in your version control system,\npowered by [Dunamai](https://github.com/mtkennerly/dunamai). Many different\nversion control systems are supported, including Git and Mercurial; please\nrefer to the Dunamai page for the full list (and minimum supported version\nwhere applicable).\n\n`poetry-dynamic-versioning` provides a build backend that patches Poetry Core\nto enable the versioning system in PEP 517 build frontends.\nWhen installed with the `plugin` feature (i.e., `poetry-dynamic-versioning[plugin]`),\nit also integrates with the Poetry CLI to trigger the versioning in commands like `poetry build`.\n\nFor Poetry 1.1.x, you can use an older version of `poetry-dynamic-versioning` (0.17.1 or earlier)\nthat relied on a `*.pth` import hack, but this is no longer supported,\nso you should migrate to the standardized plugin and Poetry 1.2.0+.\n\n## Installation\nIf you\'ve previously installed the deprecated `poetry-dynamic-versioning-plugin` package,\nbe sure to uninstall it before proceeding.\n\n* Run: `poetry self add "poetry-dynamic-versioning[plugin]"`\n* Add this section to your pyproject.toml:\n  ```toml\n  [tool.poetry-dynamic-versioning]\n  enable = true\n  ```\n* Include the plugin in the `build-system` section of pyproject.toml\n  for interoperability with PEP 517 build frontends:\n\n  ```toml\n  [build-system]\n  requires = ["poetry-core>=1.0.0", "poetry-dynamic-versioning"]\n  build-backend = "poetry_dynamic_versioning.backend"\n  ```\n\n  This is a thin wrapper around `poetry.core.masonry.api`.\n\nPoetry\'s typical `version` setting is still required in `[tool.poetry]`,\nbut you are encouraged to use `version = "0.0.0"` as a standard placeholder.\n\nWith the minimal configuration above, the plugin will automatically take effect\nwhen you run commands such as `poetry build`. It will update the version in\npyproject.toml, then revert the change when the plugin deactivates. If you want\nto include a `__version__` variable in your code, just put a placeholder in the\nappropriate file and configure the plugin to update it (see below) if it isn\'t\none of the defaults. You are encouraged to use `__version__ = "0.0.0"` as a\nstandard placeholder.\n\n## Configuration\nIn your pyproject.toml file, you may configure the following options:\n\n* `[tool.poetry-dynamic-versioning]`: General options.\n  * `enable` (boolean, default: false): Since the plugin has to be installed\n    globally, this setting is an opt-in per project. This setting will likely\n    be removed once plugins are officially supported.\n  * `vcs` (string, default: `any`): This is the version control system to check for a version.\n    One of: `any`, `git`, `mercurial`, `darcs`, `bazaar`, `subversion`, `fossil`, `pijul`.\n  * `metadata` (boolean, default: unset): If true, include the commit hash in\n    the version, and also include a dirty flag if `dirty` is true. If unset,\n    metadata will only be included if you are on a commit without a version tag.\n    This is ignored when `format` or `format-jinja` is used.\n  * `tagged-metadata` (boolean, default: false): If true, include any tagged\n    metadata discovered as the first part of the metadata segment.\n    Has no effect when `metadata` is set to false.\n    This is ignored when `format` or `format-jinja` is used.\n  * `dirty` (boolean, default: false): If true, include a dirty flag in the\n    metadata, indicating whether there are any uncommitted changes.\n    Has no effect when `metadata` is set to false.\n    This is ignored when `format` or `format-jinja` is used.\n  * `pattern` (string): This is a regular expression which will be used to find\n    a tag representing a version. When this is unset, Dunamai\'s default pattern is used.\n\n    There must be a capture group named `base`\n    with the main part of the version. Optionally, it may contain another two\n    groups named `stage` and `revision` for prereleases, and it may contain a\n    group named `tagged_metadata` to be used with the `tagged-metadata` option.\n    There may also be a group named `epoch` for the PEP 440 concept.\n\n    If the `base` group is not included, then this will be interpreted as a\n    named preset from the Dunamai `Pattern` class. This includes:\n    `default`, `default-unprefixed` (makes the `v` prefix optional).\n\n    You can check the default for your installed version of Dunamai by running this command:\n    ```\n    poetry run python -c "import dunamai; print(dunamai.Pattern.Default.regex())"\n    ```\n\n    Remember that backslashes must be escaped (`\\\\`) in the TOML file.\n  * `format` (string, default: unset): This defines a custom output format for\n    the version. Available substitutions:\n\n    * `{base}`\n    * `{stage}`\n    * `{revision}`\n    * `{distance}`\n    * `{commit}`\n    * `{dirty}`\n    * `{tagged_metadata}`\n    * `{branch}`\n    * `{branch_escaped}` which omits any non-letter/number characters\n    * `{timestamp}` of the current commit, which expands to YYYYmmddHHMMSS as UTC\n\n    Example: `v{base}+{distance}.{commit}`\n  * `format-jinja` (string, default: unset): This defines a custom output format\n    for the version, using a [Jinja](https://pypi.org/project/Jinja2) template.\n    When this is set, `format` is ignored.\n\n    Available variables:\n\n    * `base` (string)\n    * `stage` (string or None)\n    * `revision` (integer or None)\n    * `distance` (integer)\n    * `commit` (string)\n    * `dirty` (boolean)\n    * `tagged_metadata` (string or None)\n    * `version` (dunumai.Version)\n    * `env` (dictionary of environment variables)\n    * `branch` (string or None)\n    * `branch_escaped` (string or None)\n    * `timestamp` (string or None)\n\n    Available functions:\n\n    * `bump_version` ([from Dunamai](https://github.com/mtkennerly/dunamai/blob/fe69436133d0ea2097a9fed1dbb31ec96263cf83/dunamai/__init__.py#L1965-L1977))\n    * `serialize_pep440` ([from Dunamai](https://github.com/mtkennerly/dunamai/blob/fe69436133d0ea2097a9fed1dbb31ec96263cf83/dunamai/__init__.py#L1863-L1886))\n    * `serialize_semver` ([from Dunamai](https://github.com/mtkennerly/dunamai/blob/fe69436133d0ea2097a9fed1dbb31ec96263cf83/dunamai/__init__.py#L1917-L1931))\n    * `serialize_pvp` ([from Dunamai](https://github.com/mtkennerly/dunamai/blob/fe69436133d0ea2097a9fed1dbb31ec96263cf83/dunamai/__init__.py#L1945-L1954))\n\n    Simple example:\n\n    ```toml\n    format-jinja = "{% if distance == 0 %}{{ base }}{% else %}{{ base }}+{{ distance }}.{{ commit }}{% endif %}"\n    ```\n\n    Complex example:\n\n    ```toml\n    format-jinja = """\n        {%- if distance == 0 -%}\n            {{ serialize_pep440(base, stage, revision) }}\n        {%- elif revision is not none -%}\n            {{ serialize_pep440(base, stage, revision + 1, dev=distance, metadata=[commit]) }}\n        {%- else -%}\n            {{ serialize_pep440(bump_version(base), stage, revision, dev=distance, metadata=[commit]) }}\n        {%- endif -%}\n    """\n    ```\n  * `format-jinja-imports` (array of tables, default: empty): This defines\n    additional things to import and make available to the `format-jinja`\n    template. Each table must contain a `module` key and may also contain an\n    `item` key. Consider this example:\n\n    ```toml\n    format-jinja-imports = [\n        { module = "foo" },\n        { module = "bar", item = "baz" },\n    ]\n    ```\n\n    This is roughly equivalent to:\n\n    ```python\n    import foo\n    from bar import baz\n    ```\n\n    `foo` and `baz` would then become available in the Jinja formatting.\n  * `style` (string, default: unset): One of: `pep440`, `semver`, `pvp`.\n    These are preconfigured output formats. If you set both a `style` and\n    a `format`, then the format will be validated against the style\'s rules.\n    If `style` is unset, the default output format will follow PEP 440,\n    but a custom `format` will only be validated if `style` is set explicitly.\n  * `latest-tag` (boolean, default: false): If true, then only check the latest\n    tag for a version, rather than looking through all the tags until a suitable\n    one is found to match the `pattern`.\n  * `bump` (boolean, default: false): If true, then increment the last part of\n    the version `base` by 1, unless the `stage` is set, in which case increment\n    the `revision` by 1 or set it to a default of 2 if there was no `revision`.\n    Does nothing when on a commit with a version tag.\n\n    Example, if there have been 3 commits since the `v1.3.1` tag:\n    * PEP 440 with `bump = false`: `1.3.1.post3.dev0+28c1684`\n    * PEP 440 with `bump = true`: `1.3.2.dev3+28c1684`\n  * `tag-dir` (string, default: `tags`): This is the location of tags relative\n    to the root. This is only used for Subversion.\n  * `tag-branch` (string, default: unset): Branch on which to find tags, if different than the\n    current branch. This is only used for Git currently.\n  * `full-commit` (boolean, default: false): If true, get the full commit hash\n    instead of the short form. This is only used for Git and Mercurial.\n  * `strict` (boolean, default: false):\n    If true, then fail instead of falling back to 0.0.0 when there are no tags.\n* `[tool.poetry-dynamic-versioning.substitution]`: Insert the dynamic version\n  into additional files other than just pyproject.toml. These changes will be\n  reverted when the plugin deactivates.\n  * `files` (array of strings): Globs for any files that need substitutions. Default:\n    `["*.py", "*/__init__.py", "*/__version__.py", "*/_version.py"]`.\n    To disable substitution, set this to an empty list.\n  * `patterns` (array of strings): Regular expressions for the text to replace.\n    Each regular expression must have two capture groups, which are any\n    text to preserve before and after the replaced text. Default:\n    `["(^__version__\\s*(?::.*?)?=\\s*[\'\\"])[^\'\\"]*([\'\\"])"]`.\n\n    Remember that the backslashes must be escaped (`\\\\`) in the TOML file.\n  * `folders` (array of tables, default: empty): List of additional folders to\n    check for substitutions.\n\n    Each table supports these options:\n\n    * `path` (string, required): Path to the folder.\n    * `files` (array of strings, optional): Override `substitution.files` for this folder.\n    * `patterns` (array of strings, optional): Override `substitution.patterns` for this folder.\n\n    If you use an `src` layout, you may want to keep the default `files`/`patterns`\n    and just specify the following:\n\n    ```toml\n    folders = [\n      { path = "src" }\n    ]\n    ```\n\n    This will check the default file globs (e.g., `./*.py`)\n    as well as the same file globs inside of `src` (e.g., `./src/*.py`).\n\nSimple example:\n\n```toml\n[tool.poetry-dynamic-versioning]\nenable = true\nvcs = "git"\nstyle = "semver"\n```\n\n## Environment variables\nIn addition to the project-specific configuration above,\nyou can apply some global overrides via environment variables.\n\n* `POETRY_DYNAMIC_VERSIONING_BYPASS`:\n  Use this to bypass the VCS mechanisms and use a static version instead.\n  This is mainly for distro package maintainers who need to patch existing releases,\n  without needing access to the original repository.\n* `POETRY_DYNAMIC_VERSIONING_COMMANDS`:\n  You can set a comma-separated list of Poetry commands during which to activate the versioning.\n  For example, `build,publish` will limit the dynamic versioning to those two commands.\n\n## Command line mode\nThe plugin also has a command line mode for execution on demand.\nThis mode applies the dynamic version to all relevant files and leaves\nthe changes in-place, allowing you to inspect the result.\nYour configuration will be detected from pyproject.toml as normal,\nbut the `enable` option is not necessary.\n\nTo activate this mode, either use `poetry dynamic-versioning` (provided by the `plugin` feature)\nor `poetry-dynamic-versioning` (standalone script with default features).\n\n## VCS archives\nSometimes, you may only have access to an archive of a repository (e.g., a zip file) without the full history.\nThe plugin can still detect a version in some of these cases.\nRefer to [the Dunamai documentation](https://github.com/mtkennerly/dunamai#vcs-archives) for more info.\n\n## Caveats\n* When using Git, remember that lightweight tags do not store their creation time.\n  Therefore, if a commit has multiple lightweight tags,\n  we cannot reliably determine which one should be considered the newest.\n  The solution is to use annotated tags instead.\n* The dynamic version is not available during `poetry run` or `poetry shell`.\n* Regarding PEP 517 support:\n\n  `pip wheel .` and `pip install .` will work with new enough Pip versions\n  that default to in-tree builds or support the `--use-feature=in-tree-build`\n  option. Older versions of Pip will not work because they create an isolated\n  copy of the source code that does not contain the version control history.\n\n  If you want to build wheels of your dependencies, you can do the following,\n  although local path-based dependencies may not work:\n\n  ```\n  poetry export -f requirements.txt -o requirements.txt --without-hashes\n  pip wheel -r requirements.txt\n  ```\n',
    'author': 'Matthew T. Kennerly',
    'author_email': 'mtkennerly@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/mtkennerly/poetry-dynamic-versioning',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
